--[[

CastTimeMonitor is meant to be a simple add-on that you can easily configure from within its .lua 
file. Just below you will find a list of 10 CTM_Options; their names are fairly self-explanatory so
only change what you need to change. I've provided some comments to help you understand what each of
options does.

The cast time frame itself can be dragged with the left mouse button if you set the "locked" option
to false, and I find it works perfectly if I have the CastTime centered on my character or just
below. If I get enough requests, I will look into creating an in-game configuration. 

*** CastTimeMonitor is Copyright 2011 by Phael of Hydraxis ***

Please do not distribute altered copies of this add-on because it can make maintaining it a 
nightmare. If you want to see a feature built into it, please add a comment on the official 
download pages on curse.com and wowinterface.com.

For now, I will take bug reports and feature requests directly in the comments sections of the 
official release channels. Until such a time that I believe I need a ticket tracking system (which
hopefully never happens), I will simply answer bug reports/feature requests in comments sections.

---------------
Version History
---------------

11/25/2011 - Version 1.0  (Initial Release)
           - Version 1.0a Fix typos in comments, add clarity to comments, removed a comment that was
			 no longer true, fixed an issue with the options
11/26/2011 - Version 1.1 Added configurable font options
11/30/2011 - Version 1.2 Optimized some code and I think I fixed a bugaboo that mysteriously cropped up

-----
To-Do
-----

- Add multiple threshold levels and multiple corresponding colors

--]]

CTM_Options = {
			SpellID = "19434", -- Aimed Shot (Find this number on Wowhead)
			xPos = "840", -- Halfway across a 1680x1050 display (figuring 100 pixels frame width)
			yPos = "475", -- 475 pixels up a 1680x1050 display
			locked = "false", -- Change to "true" if you don't want to be able to drag the frame
			targetCastTime = 1.8, -- The cast time at which CTM will change colors
			targetPower = 50, -- The focus/mana/energy/rage/runic power at which CTM changes color
			buff = "Fire!", -- Name of a buff to look for. Make this the exact name if you use it
			
	--[[	Font options - To change the font, first put your desired font file into the Fonts
			folder in this add-on's folder. Next, just change the file name in the "font" option
			below. For instance, change "Interface\\AddOns\\CastTimeMonitor\\Fonts\\visitor1.ttf" to
			"Interface\\AddOns\\CastTimeMonitor\\Fonts\\skurri.ttf" if you want to use Skurri. 
	--]]
			font = "Interface\\AddOns\\CastTimeMonitor\\Fonts\\visitor1.ttf", 
			fontSize = 20,
			fontOutline = "THICKOUTLINE,MONOCHROME"
			
	--[[	The fontOutline option will be either "OUTLINE", "THICKOUTLINE", "OUTLINE,MONOCHROME",
			or "THICKOUTLINE,MONOCHROME". Monochrome outlines look great with pixel fonts.		
	--]]
			}		

function CastTimeMonitorFrame_OnMouseDown()
	if CTM_Options.locked == "false" then
		CastTimeMonitorFrame:StartMoving()
	end
end

function CastTimeMonitorFrame_OnMouseUp()
	if CTM_Options.locked == "false" then
		CastTimeMonitorFrame:StopMovingOrSizing()
	end
end

function CastTimeMonitor_OnLoad()
	CastTimeMonitorFrame:RegisterEvent("ADDON_LOADED")
	CastTimeMonitorFrame:RegisterEvent("UNIT_AURA")
	CastTimeMonitorFrame:RegisterEvent("UNIT_POWER")
	CastTimeMonitorFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
	CastTimeMonitorFrame:SetPoint("BOTTOMLEFT", UIParent, "BOTTOMLEFT", CTM_Options.xPos, CTM_Options.yPos)
	CastTimeMonitorFrame:CreateFontString("CastTime", "ARTWORK")
	CastTime:SetPoint("TOPLEFT", 0, "BOTTOMLEFT")
	CastTime:SetJustifyH("CENTER")
	CastTime:SetJustifyV("MIDDLE")
	CastTime:SetFont(CTM_Options.font, CTM_Options.fontSize, CTM_Options.fontOutline)
end

function GetCastTime()
	local _,_,_,_,_,_,castTime = GetSpellInfo(CTM_Options.SpellID)
	castTime = castTime / 1000
	return castTime
end

function GetPowerLevel()
	local powerLevel = UnitPower("player")
	return powerLevel
end

function GetFireBuff()
	local fireBuff = UnitBuff("player", CTM_Options.buff)
	return fireBuff
end

function CastTimeMonitor_OnEvent(event, var1, var2)

	if event == "PLAYER_ENTERING_WORLD" or event == "ADDON_LOADED" then
		CastTime:SetText(GetCastTime())
	end
	
	if event == "UNIT_AURA" and var1 == "player" then 
		CastTime:SetText(GetCastTime())
	end
	
	if GetCastTime() > CTM_Options.targetCastTime or GetPowerLevel() < CTM_Options.targetPower then 
		CastTime:SetTextColor(1, 0, 0, 1)
		CastTime:SetText(GetCastTime())
	end
	
	if GetCastTime() <= CTM_Options.targetCastTime and GetPowerLevel() >= CTM_Options.targetPower then
		CastTime:SetTextColor(0, 1, 0, 1)
		CastTime:SetText(GetCastTime())
	end
	
	if GetFireBuff() == CTM_Options.buff then
		CastTime:SetTextColor(0, 1, 0, 1)
		CastTime:SetText(GetCastTime())
	end
end